@@ -1,6 +1,8 @@
 """ Script used by pykwalify to validate config file.
 The nullable option is derived to control if an optional rule has some empty keys.
 """
+from pykwalify.errors import SchemaError
+
 
 STRING_TYPE = {"text", "str"}
 
@@ -9,15 +11,17 @@ def check_optionnal(value, rule_obj):
     for key, rule in rule_obj.mapping.items():
         if rule.type in STRING_TYPE and rule.required and not rule.nullable:
             try:
-                yield len(value[key]) > 0
+                yield key, len(value[key]) > 0
             except TypeError:
-                yield False
+                yield key, False
         else:
-            yield True
+            yield key, True
 
 
 def ext_map_optionnal(value, rule_obj, path):
     todo = value.get("do")
     if todo:
-        return all([value_check for value_check in check_optionnal(value, rule_obj)])
+        for key, value_check in check_optionnal(value, rule_obj):
+            if not value_check:
+                raise SchemaError(f"Mandatory value is missing at {path}/{key}")
     return True
