@@ -54,6 +54,7 @@ class SequanaManager:
                 job=1
                 force = True
                 use_apptainer = False
+                apptainer_prefix = ""
                 def __init__(self):
                     pass
             from sequana_pipetools import SequanaManager
@@ -132,10 +133,12 @@ class SequanaManager:
 
         if self.options.apptainer_prefix:  # pragma: no cover
             self.apptainer_prefix = self.options.apptainer_prefix
+            self.local_apptainers = False
         else:  # pragma: no cover
             self.apptainer_prefix = os.environ.get(
                 "SEQUANA_SINGULARITY_PREFIX", f"{self.workdir}/.sequana/apptainers"
             )
+            self.local_apptainers = True
 
     def exists(self, filename, exit_on_error=True, warning_only=False):  # pragma: no cover
         """This is a convenient function to check if a directory/file exists
@@ -179,6 +182,11 @@ class SequanaManager:
             if pipeline_path.exists():
                 return pipeline_path / "data"
 
+            # if it does not exist, this may be a "develop" mode.
+            pipeline_path = Path(site_package) / f"sequana-{self.name}.egg-link"
+            if pipeline_path.exists():
+                return pipeline_path / "data"
+
         logger.error(f"package provided ({self.name}) not installed.")
         raise PipetoolsException
 
@@ -251,7 +259,10 @@ class SequanaManager:
                 self.command += f" --use-singularity {apptainer_args}"
 
             # finally, the prefix where images are stored
-            self.command += f" --singularity-prefix {self.apptainer_prefix} "
+            if self.local_apptainers:
+                self.command += f" --singularity-prefix .sequana/apptainers"
+            else:
+                self.command += f" --singularity-prefix {self.apptainer_prefix} "
 
         # FIXME a job is not a core. Ideally, we should add a core option
         if self._guess_scheduler() == "local":
@@ -365,7 +376,10 @@ class SequanaManager:
             }
 
             if self.options.use_apptainer:  # pragma: no cover
-                options["apptainer_prefix"] = self.apptainer_prefix
+                if self.local_apptainers:
+                    options["apptainer_prefix"] = ".sequana/apptainers"
+                else:
+                    options["apptainer_prefix"] = self.apptainer_prefix
                 home = str(Path.home())
                 options["apptainer_args"] = self.options.apptainer_args
 
